#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor openSUSE%nil
%if "%{flavor}" == ""
%define branding_name %{nil}
ExclusiveArch:  do-not-build
%else
%define branding_name %{flavor}
%define dash -
%if "%{flavor}" == "SLED"
%define build_SLED 1
%else
%define build_openSUSE 1
%endif
%if (0%{?build_SLED} && 0%{?is_opensuse}) || (0%{?build_openSUSE} && ! 0%{?is_opensuse})
# Don't build SLE branding on openSUSE and vice-versa
ExclusiveArch:  do-not-build
%endif
%endif

%define gnome_menus_version %(rpm -q --qf '%%{version}' gnome-menus)
Name:           gnome-menus-branding%{?dash}%{branding_name}
Version:        42.1
Release:        2.5
Summary:        The GNOME Desktop Menu -- %{branding_name} Menus Definitions
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            http://www.gnome.org
Source:         gnome-menus-branding-COPYING
# PATCH-FIX-OPENSUSE gnome-menus-branding-remove-X-SuSE-ControlCenter.patch vuntz@opensuse.org -- Remove the desktop files with X-SuSE-YaST category from the Applications menu and explicitly add YaST launcher
Patch0:         gnome-menus-branding-remove-X-SuSE-ControlCenter.patch
BuildRequires:  gnome-menus
# To be in sync with upstream defaults, do branding as a patch for upstream file.
# WARNING: As this package conflicts with gnome-menus-branding-%{branding_name}, you cannot
#          reuse build root. You have to build in a clean build root every time!
BuildRequires:  gnome-menus-branding-upstream
Requires:       gnome-menus = %{gnome_menus_version}
Supplements:    packageand(gnome-menus:branding-%{branding_name})
Conflicts:      gnome-menus-branding
Provides:       gnome-menus-branding = %{gnome_menus_version}
BuildArch:      noarch

%description
The package contains an implementation of the draft "Desktop Menu
Specification" from freedesktop.org:

http://www.freedesktop.org/Standards/menu-spec

This package provides the %{branding_name} definitions for menus.

%prep
%setup -q -T -c %{name}-%{version}
cp -a %{SOURCE0} COPYING
# We will base menus on upstream menus:
cp -a %{_sysconfdir}/xdg/menus/*.menu .
%patch -P 0

%build

%install
install -d %{buildroot}%{_sysconfdir}/xdg/menus
install -m0644 *.menu %{buildroot}%{_sysconfdir}/xdg/menus/

%files
%license COPYING
%{_sysconfdir}/xdg/menus/gnome-applications.menu

%changelog
* Tue Nov 28 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -p N instead of deprecated %%patchN.
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Convert package to _multibuild.
* Thu Jan  3 2019 bjorn.lie@gmail.com
- Rebase gnome-menus-branding-remove-X-SuSE-ControlCenter.patch.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec file using spec-cleaner.
* Mon Oct 12 2015 zaitor@opensuse.org
- Bump version to 42.1, to prepare for next version of openSUSE.
* Sat Aug 23 2014 zaitor@opensuse.org
- Bump version to 13.2, to prepare for next version of openSUSE.
* Thu Oct  3 2013 dimstar@opensuse.org
- Rebased gnome-menus-branding-remove-X-SuSE-ControlCenter.patch
  on top of gnome-menus 3.10.0.
* Sun Sep  8 2013 zaitor@opensuse.org
- Bump version to 13.1, to prepare for next version of openSUSE.
* Wed Mar  6 2013 dimstar@opensuse.org
- Rebase gnome-menus-branding-remove-X-SuSE-ControlCenter.patch on
  top of gnome-menus 3.7.90.
* Wed May 23 2012 vuntz@opensuse.org
- Bump version to 12.2, to prepare for next version of openSUSE.
* Thu Oct 13 2011 vuntz@opensuse.org
- Remove %%{release} from the gnome-menus versioned Requires, to not
  have to rebuild this package each time gnome-menus rebuilds to
  keep it installable.
* Fri Jul 22 2011 vuntz@opensuse.org
- Drop gnome-menus-branding-settings.menu source: we do not install
  a settings.menu file, since upstream doesn't ship one either.
  Fix bnc#703818.
* Thu Jul  7 2011 vuntz@opensuse.org
- Change License tag from BSD3c to LGPLv2.1+: since we base our
  branding on the one from upstream, we inherit the license.
* Wed Jul  6 2011 vuntz@opensuse.org
- Bump version to 12.1.
- Add a Requires for gnome-menus, since the branding package is
  useless without it.
- Update summary and description.
- Add Url tag.
* Wed Apr 27 2011 vuntz@opensuse.org
- Update gnome-menus-branding-remove-X-SuSE-ControlCenter.patch:
  instead of excluding X-SuSE-ControlCenter-* categories, simply
  exclude X-SuSE-YaST. We might still want to see .desktop files
  with X-SuSE-ControlCenter-* in Other as the control center won't
  display them anymore.
* Wed Apr 27 2011 fcrozat@novell.com
- Update gnome-menus-branding-remove-X-SuSE-ControlCenter.patch:
  Ensure YaST launcher is visible in System category.
* Fri Oct  8 2010 vuntz@opensuse.org
- Bump version to 11.4.
* Tue Sep 21 2010 vuntz@opensuse.org
- Drop gnome-menus-branding-Hidden.directory: this is needed for
  the applications.menu file from desktop-data-openSUSE. But it's
  weird to have the file in a different package. Instead, we'll fix
  desktop-data-openSUSE to use a file it already ships.
* Mon Sep 13 2010 vuntz@opensuse.org
- Add gnome-menus-branding-remove-X-SuSE-ControlCenter.patch: this
  removes the desktop files with X-SuSE-ControlCenter-* categories
  from the Applications menu. They should just appear in the
  control center.
- Rename gnome-menus-branding.changes to
  gnome-menus-branding.changes.in.
* Sat Jan 16 2010 vuntz@opensuse.org
- Merge openSUSE and SLED branding packaging, and generate the
  packages from the same sources.
- Change version to 11.3.
- Rename gnome-menus-branding-openSUSE-COPYING to
  gnome-menus-branding-COPYING,
  gnome-menus-branding-openSUSE-Hidden.directory to
  gnome-menus-branding-Hidden.directory and
  gnome-menus-branding-openSUSE-settings.menu to
  gnome-menus-brandingsettings.menu.
- Make sure to provide the right version of gnome-menus-branding,
  based on the version of the gnome-menus package.
- Remove update-desktop-files BuildRequires.
* Thu Jul 30 2009 vuntz@novell.com
- Update gnome-menus-branding-openSUSE-settings.menu:
  + make it closer to the gnomecc.menu from upstream
  + remove usage of old X-Ximian categories that are not in use
    anymore
  + remove some of the previously included YaST tools, they don't
    make sense most of the time there.
* Sun Jan 25 2009 vuntz@novell.com
- Remove duplicate category in settings.menu
- Remove old hack to keep some preferences.menu compatibility file.
  It should not be needed anymore with the packages we have now.
* Tue Nov  4 2008 vuntz@novell.com
- Upstream has changed the way settings.menu is used for 2.24, so
  kill preferences.menu and just use settings.menu now.
- Keep preferences.menu as a link to settings.menu, since we don't
  want to break anything because of this.
- Conflicts with other branding providers.
- Spec cleanup.
* Thu Jul 31 2008 sbrabec@suse.cz
- New SuSE package (fate#303889).
